# ozobot-common

Common utilities and helpers for Ozobot projects. See the [monorepo](https://github.com/ozobot/python-libraries) for more details. 

## Features

- **Binary protocol utils**: Tools for handling serialization, locks and conversion
- **Async Utilities**: Enhanced async task management with `CancellableTaskGroup`
- **Logging**: Configurable logging setup with Loguru
- **Exceptions**: Base exception structure used by other libraries
